import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Button, Input, InputNumber } from 'antd'
import './index.scss'


class UniqueForm extends Component {
  static propTpyes = {
    dict: PropTypes.object,         // 字典项
    range: PropTypes.any,           // 字典项
    columnChange: PropTypes.func    // 修改函数
  }

  state = {
    editItem: null // 编辑元素
  }

  edit = (record) => {
    this.setState({
      editItem: record
    })

    this.props.form.setFieldsValue({
      Column: record.Column,
      Text: record.Text,
      Width: record.Width,
    })
  }


  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        values.uuid = this.state.editItem ? this.state.editItem.uuid : ''

        this.props.columnChange(values)
        this.setState({
          editItem: null
        })
        this.props.form.setFieldsValue({
          Column: '',
          Text: '',
          Width: 20,
        })
      }
    })
  }

  render() {
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <Form {...formItemLayout} className="verify-form">
        <Row gutter={24}>
          <Col span={7}>
            <Form.Item label={'Column'}>
              {getFieldDecorator('Column', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: this.props.dict['form.required.input'] + 'Column!'
                  }
                ]
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={7}>
            <Form.Item label={'Text'}>
              {getFieldDecorator('Text', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: this.props.dict['form.required.input'] + 'Text!'
                  }
                ]
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={7}>
            <Form.Item label={'Width'}>
              {getFieldDecorator('Width', {
                initialValue: 20,
                rules: [
                  {
                    required: true,
                    message: this.props.dict['form.required.input'] + 'Width!'
                  }
                ]
              })(<InputNumber min={5} max={200} precision={0} />)}
            </Form.Item>
          </Col>
          <Col span={3} className="add">
            <Button onClick={this.handleConfirm} type="primary" className="add-row">
              确定
            </Button>
          </Col>
          {/* <Col span={7}>
            <Form.Item label={'类型'}>
              {getFieldDecorator('type', {
                initialValue: 'text'
              })(
                <Select onChange={this.typeChange}>
                  <Select.Option value="text"> text </Select.Option>
                  <Select.Option value="number"> number </Select.Option>
                </Select>
              )}
            </Form.Item>
          </Col> */}
        </Row>
      </Form>
    )
  }
}

export default Form.create()(UniqueForm)